@@ -37,11 +37,16 @@ class MessageTextFieldPrivate
 public:
   MessageTextFieldPrivate()
   : codec(&gsmCodec)
+  , displayMode(MessageTextField::PlatformDisplayMode)
   {
   }
 
   QGsmCodec gsmCodec;
   QTextCodec* codec;
+  MessageTextField::DisplayMode displayMode;
+
+  QPalette standardPalette;
+  QPalette platformPalette;
 };
 
 //////////////////////////////////////////////////////////////////////////
@@ -52,12 +57,15 @@ MessageTextField::MessageTextField(QWidget* parent /* = 0 */)
 : QPlainTextEdit(parent)
 , d(new MessageTextFieldPrivate)
 {
+  // Save the palettes
+  d->standardPalette = palette();
+
 #ifdef Q_WS_MAEMO_5
   // Adjust the palette a little bit to stay with the Maemo style
-  QPalette palette = this->palette();
-  palette.setColor(QPalette::Text, palette.color(QPalette::Base));
-  palette.setColor(QPalette::Base, palette.color(QPalette::Window));
-  setPalette(palette);
+  d->platformPalette = palette();
+  d->platformPalette.setColor(QPalette::Text, d->platformPalette.color(QPalette::ButtonText));
+  d->platformPalette.setColor(QPalette::Base, d->platformPalette.color(QPalette::Window));
+  setPalette(d->platformPalette);
 
   // Maemo style has no frame
   setFrameShape(QFrame::NoFrame);
@@ -73,6 +81,46 @@ MessageTextField::~MessageTextField()
 
 //////////////////////////////////////////////////////////////////////////
 
+void MessageTextField::setDisplayMode(DisplayMode displayMode)
+{
+  // Don't set twice
+  if ( d->displayMode == displayMode )
+    return;
+
+  // Remember the display mode
+  d->displayMode = displayMode;
+
+#ifdef Q_WS_MAEMO_5
+  switch(displayMode)
+  {
+  case StandardDisplayMode:
+    setPalette(d->standardPalette);
+    setFrameShape(QFrame::StyledPanel);
+    break;
+
+  case PlatformDisplayMode:
+    setPalette(d->platformPalette);
+    setFrameShape(QFrame::NoFrame);
+    break;
+
+  default:
+    break;
+  }
+#endif // Q_WS_MAEMO_5
+
+  // Schedule the redraw event
+  update();
+}
+
+//////////////////////////////////////////////////////////////////////////
+
+MessageTextField::DisplayMode MessageTextField::displayMode() const
+{
+  return d->displayMode;
+}
+
+//////////////////////////////////////////////////////////////////////////
+
 /*void MessageTextField::setCodec(QTextCodec* codec)
 {
   if ( d->codec == codec )
@@ -115,26 +163,30 @@ void MessageTextField::keyPressEvent(QKeyEvent* event)
 void MessageTextField::paintEvent(QPaintEvent* event)
 {
 #ifdef Q_WS_MAEMO_5
-  // Draw the underlines like in the Maemo conversations application
-  QFontMetrics fontMetrics = this->fontMetrics();
-  QRect rect = this->rect();
+  // Draw "prettier" on Maemo?
+  if ( d->displayMode == PlatformDisplayMode )
+  {
+    // Draw the underlines like in the Maemo conversations application
+    QFontMetrics fontMetrics = this->fontMetrics();
+    QRect rect = this->rect();
 
-  // The line color is taken from the Conversations application
-  QColor lineColor(32, 32, 32);
-  
-  // Setup the painter
-  QPainter painter;
-  painter.begin(viewport());
-  painter.setPen( QPen(lineColor) );
+    // The line color is taken from the Conversations application
+    QColor lineColor(32, 32, 32);
 
-  // Define a jump offset
-  int jump = fontMetrics.lineSpacing(); //fontMetrics.ascent() + fontMetrics.underlinePos();
+    // Setup the painter
+    QPainter painter;
+    painter.begin(viewport());
+    painter.setPen( QPen(lineColor) );
 
-  // Draw the lines
-  for(int y=contentOffset().y()+jump; y < rect.height(); y += jump)
-    painter.drawLine(rect.left(), y, rect.right(), y);
+    // Define a jump offset
+    int jump = fontMetrics.lineSpacing(); //fontMetrics.ascent() + fontMetrics.underlinePos();
 
-  painter.end();
+    // Draw the lines
+    for(int y=contentOffset().y()+jump; y < rect.height(); y += jump)
+      painter.drawLine(rect.left(), y, rect.right(), y);
+
+    painter.end();
+  }
 #endif // Q_WS_MAEMO_5
 
   QPlainTextEdit::paintEvent(event);
