@@ -55,6 +55,7 @@ public:
   // Properties
   Ui_MessageWidget ui;
 
+  Settings settings;
   QPointer<ProviderInterface> provider;
   MessageTypeModel messageTypeModel;
 
@@ -68,6 +69,8 @@ public:
   void init();
   QLayout* setupPortraitLayout();
 
+  void applySettings(const Settings& settings);
+
 public slots:
   void updateUi();
 
@@ -88,14 +91,14 @@ public slots:
 void MessageWidgetPrivate::init()
 {
   // Setup the orientation helper
-  orientationHelper.setWidget(self);
+  //orientationHelper.setWidget(self);
 
   // Setup the ui
   ui.setupUi(self);
 
   // Setup the layouts
-  orientationHelper.setLandscapeLayout(ui.verticalLayout);
-  orientationHelper.setPortraitLayout( setupPortraitLayout() );
+  //orientationHelper.setLandscapeLayout(ui.verticalLayout);
+  //orientationHelper.setPortraitLayout( setupPortraitLayout() );
 
   QMenuBar* menuBar = new QMenuBar(self);
   QMenu* menu = menuBar->addMenu( QString() );
@@ -140,6 +143,14 @@ QLayout* MessageWidgetPrivate::setupPortraitLayout()
 
 //////////////////////////////////////////////////////////////////////////
 
+void MessageWidgetPrivate::applySettings(const Settings& settings)
+{
+  // Adjust the display mode
+  ui.messageText->setDisplayMode( settings.usePlatformDisplayMode() ? MessageTextField::PlatformDisplayMode : MessageTextField::StandardDisplayMode );
+}
+
+//////////////////////////////////////////////////////////////////////////
+
 void MessageWidgetPrivate::updateUi()
 {
   QVariant messageTypeData = messageTypeModel.index(ui.messageTypePicker->currentIndex()).data(MessageTypeModel::MessageTypeRole);
@@ -268,13 +279,32 @@ void MessageWidgetPrivate::onChooseContactButtonClicked()
     {
       // Try to convert the number to an international format
       QString number = contact.number();
-      if ( !make_number_international(number) )
+
+      if ( !settings.prefixNumbers() && !isInternationalNumber(number) )
       {
-        QMessageBox::critical(self, tr("Wrong number format"),
-            tr("%1's phone number \"%2\" could not be converted to an international format.").arg(contact.name()).arg(number));
-      
+        QMessageBox::critical(self, tr("Wrong number format"), 
+                                    tr("%1's phone number \"%2\" is not international. Automatic prefixing is disabled.").arg(contact.name()).arg(number));
+
         continue;
       }
+      else if ( settings.prefixNumbers() )
+      {
+        bool wasPrefixed = false;
+        QString prefix = settings.prefix();
+        if ( !make_number_international(prefix, &number, &wasPrefixed) )
+        {
+          QMessageBox::critical(self, tr("Wrong number format"),
+                                      tr("%1's phone number \"%2\" could not be converted to an international format.").arg(contact.name()).arg(number));
+
+          continue;
+        }
+
+        if ( wasPrefixed && settings.notifyOnPrefix() )
+        {
+          QMessageBox::information(self, tr("Automatic prefixing"),
+                                         tr("%1's phone number was automatically prefixed from %2 to: %3").arg(contact.name()).arg(contact.number()).arg(number));
+        }
+      }
 
       // Set the contacts' number back
       contact.setNumber(number);
@@ -298,6 +328,13 @@ void MessageWidgetPrivate::onSendButtonClicked()
 
   // Ensure the message fits the settings
   QString messageText = ui.messageText->toPlainText();
+
+  if ( messageText.isEmpty() )
+  {
+    onError( tr("Your message is empty!") );
+    return;
+  }
+
   if ( messageType.maxMessageLength() != -1 && messageText.size() > messageType.maxMessageLength() )
   {
     onError( tr("The message is too long! This message type only supports %n character(s).", "", messageType.maxMessageLength()) );
@@ -318,6 +355,7 @@ void MessageWidgetPrivate::onSendButtonClicked()
     return;
   }
 
+  // Setup the progress dialog
   QProgressDialog* progressDialog = new QProgressDialog(self);
   progressDialog->setAttribute(Qt::WA_DeleteOnClose);
   progressDialog->setWindowTitle( tr("Sending SMS ...") );
@@ -456,6 +494,24 @@ MessageType MessageWidget::currentMessageType() const
   return qvariant_cast<MessageType>( index.data(MessageTypeModel::MessageTypeRole) );
 }
 
+//////////////////////////////////////////////////////////////////////////
+
+void MessageWidget::setSettings(const Settings& settings)
+{
+  // Take the settings
+  d->settings = settings;
+
+  // And apply them
+  d->applySettings(settings);
+}
+
+//////////////////////////////////////////////////////////////////////////
+
+Settings MessageWidget::settings() const
+{
+  return d->settings;
+}
+
 //////////////////////////////////////////////////////////////////////////
 //////////////////////////////////////////////////////////////////////////
 //////////////////////////////////////////////////////////////////////////
