@@ -159,6 +159,7 @@ public:
 
     // We define some default urls (may be replaced by code later)
     urls.preLoginUrl      = QUrl("http://www.o2online.de");
+    urls.loginUrl         = QUrl("https://login.o2online.de/auth/login");
     urls.logoutUrl        = QUrl("https://login.o2online.de/loginRegistration/loginAction.do?_flowId=logout");
     urls.smsCenterUrl     = QUrl("https://email.o2online.de/smscenter_new.osp");
     urls.smsCenterSendUrl = QUrl("https://email.o2online.de/smscenter_send.osp");
@@ -280,15 +281,15 @@ void o2GermanyPrivate::handlePreLogin(QNetworkReply* reply)
   QString data = QString::fromUtf8(readData.constData(), readData.size());
 
   // Find the login url
-  QRegExp formExp("loginForm\" action=\"([^\"]*)\"");
-  if ( formExp.indexIn(data) != -1 )
+  //QRegExp formExp("loginForm\" action=\"([^\"]*)\"");
+  //if ( formExp.indexIn(data) != -1 )
   {
     // Set the login url
-    urls.loginUrl = QUrl(formExp.cap(1));
+    //urls.loginUrl = QUrl(formExp.cap(1));
 
-    QRegExp urlExp("<a href=\"([^\"]*).*title=\"E-Mail\">");
-    if ( urlExp.indexIn(data, formExp.pos() + formExp.matchedLength()) != -1 )
-      urls.comCenterUrl = urlExp.cap(1);
+    //QRegExp urlExp("<a href=\"([^\"]*).*title=\"E-Mail\">");
+    //if ( urlExp.indexIn(data, formExp.pos() + formExp.matchedLength()) != -1 )
+    //  urls.comCenterUrl = urlExp.cap(1);
 
     // Ok, the fields are known:
     // loginName
@@ -307,14 +308,14 @@ void o2GermanyPrivate::handlePreLogin(QNetworkReply* reply)
 
     post(request, formData, Login);
   }
-  else
+  /*else
   {
     // Emit that we did not find the loginForm
     emit self->error( tr("loginForm could not be found!") );
 
     // Emit that the login failed
     emit self->loginReply(false);
-  }
+  }*/
 }
 
 //////////////////////////////////////////////////////////////////////////
